## More Beautiful Python

Make Python even more beautiful :) This package includes implementations that you wish were in the standard library.

### Setup

    python -m pip install mbp
    python -m mbp.info
    =================================== More Beautiful Python ===================================
    examples              https://github.com/sudongqi/MoreBeautifulPython/blob/main/examples.py
    execution_directory   C:\Users\usr\MoreBeautifulPython
    library_path          C:\Users\usr\MoreBeautifulPython\src\mbp\core.py
    cpu_count             16
    version               1.x.x
    =============================================================================================

### Examples

https://github.com/sudongqi/MoreBeautifulPython/blob/main/examples.py

- replacement for logging
- replacement for multiprocessing
- syntax sugar for common utilities
- tools for file system & data handling
- tools for summarizations
- tools for simple statistics
- tools for llm (Large Language Model)
